#
# spec file
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%{?sle15_python_module_pythons}
Name:           python-py7zr%{psuffix}
Version:        0.20.5
Release:        2.1
Summary:        Library and utility to support 7zip
License:        LGPL-2.1-or-later
Group:          Development/Languages/Python
URL:            https://github.com/miurahr/py7zr
Source0:        https://files.pythonhosted.org/packages/source/p/py7zr/py7zr-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools >= 63}
BuildRequires:  %{python_module setuptools_scm >= 7.0.5}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Brotli >= 1.0.9
Requires:       python-multivolumefile >= 0.2.3
Requires:       python-psutil
Requires:       python-pybcj >= 0.6.0
Requires:       python-pycryptodomex >= 3.6.6
Requires:       python-pyzstd >= 0.14.4
Requires:       python-texttable
Requires:       (python-pyppmd >= 0.18.1 with python-pyppmd < 1.1.0)
%if 0%{?python_version_nodots} < 38
Requires:       python-importlib_metadata
%endif
%if 0%{?python_version_nodots} > 36
Requires:       python-inflate64 >= 0.3.1
%endif
Requires(post): update-alternatives
Requires(postun):update-alternatives
%if %{with test}
BuildRequires:  %{python_module py-cpuinfo}
BuildRequires:  %{python_module py7zr = %{version}}
BuildRequires:  %{python_module pyannotate}
BuildRequires:  %{python_module pytest-benchmark}
BuildRequires:  %{python_module pytest-remotedata}
BuildRequires:  %{python_module pytest-timeout}
BuildRequires:  %{python_module pytest}
%endif
BuildArch:      noarch
%python_subpackages

%description
py7zr is a library and utility to support 7zip archive compression, decompression, encryption and decryption written by Python programming language.

%prep
%setup -q -n py7zr-%{version}
# remove shebangs from source
sed -i '1{/#!/d}' py7zr/*.py

%if !%{with test}
%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/py7zr
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if %{with test}
%check
%pytest
%endif

%post
%python_install_alternative py7zr

%postun
%python_uninstall_alternative py7zr

%if !%{with test}
%files %{python_files}
%license LICENSE
%doc README.rst docs/Changelog.rst
%{python_sitelib}/py7zr
%{python_sitelib}/py7zr-%{version}*-info
%python_alternative %{_bindir}/py7zr
%endif

%changelog
* Wed Jun 21 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Thu May  4 2023 Dirk Müller <dmueller@suse.com>
- update to 0.20.5:
  * Remove root reference from file names (#513)
  * fix typo in the readme (#510)
  * Drop manual GC to improve performance when many files are
    handled. (#489, #490)
  * Fix mypy error
  * Skip deflate64 compression/decompression test on pypy
  * There is an issue in dependency inflate64 library that causes
    SIGABORT and SIGSEGV on pypy
* Wed Dec 21 2022 Ben Greiner <code@bnavigator.de>
- Update to 0.20.2
  * Fix error with good path data, when detecting wrong path with
    new canonical_path(), and drop resolve() call on path.
- Release 0.20.1
  [#]# Security
  * Fix sanity check for path traversal attack(#480)
  * Add path checker in writef() and writestr() methods that
    ignores evil pass.
  - When pass arcname as evil path such as
    "../../../../tmp/evil.sh"
  - it raises ValueError
  * Check symlink and junction is under target folder when
    extraction
- Release 0.20.0
  * Support enhanced deflate compression.(#472)
  * Bump setuptools@63 and setuptools_scm@7 (#473)
  * Deprecate Python 3.6 support (#473)
- Fixes boo#1206141 CVE-2022-44900
* Fri Jul 15 2022 Ben Greiner <code@bnavigator.de>
- Update to version 0.19.0
  * big changelog
- Move tests to multibuild
* Thu Jul 14 2022 Ben Greiner <code@bnavigator.de>
- Remove ancient python-pathlib from the build requirements but
  leave the version as is. An update to the latest version 0.19.0
  would require to package many more dependencies.
- Clean up the spec-file a little bit
- Use pytest. No pure python package should ever be untested.
* Sat Apr  3 2021 Ismail Dönmez <idonmez@suse.com>
- Fix sed line to use python3 and add a replacement for /usr/bin/python
  as well.
* Fri Jan 22 2021 ecsos <ecsos@opensuse.org>
- Initial version 0.11.3
